@@ -5,12 +5,14 @@ package Config::AutoConf::INI;
 use Carp                   qw/croak/;
 use Config::AutoConf 0.313 qw//;
 use Config::INI::Reader    qw//;
+use File::Basename         qw/fileparse/;
+use File::Path             qw/make_path/;
 use Scalar::Util           qw/looks_like_number blessed/;
 use parent                 qw/Config::AutoConf/;
 
 # ABSTRACT: Drive Config::AutoConf with an INI file
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -64,7 +66,7 @@ sub check {
     $self->_process_from_config(section    => 'alignof_types',  stub_name => 'check_alignof_type', args => \&_args_check);
     $self->_process_from_config(section    => 'members',        stub_name => 'check_member',       args => \&_args_check);
 
-    $self->_process_from_config(section    => 'outputs',        stub_name => 'write_config_h');
+    $self->_process_from_config(section    => 'outputs',        stub_name => '_write_config_h');
 
     delete $self->{_config_ini};
     delete $self->{_headers_ok};
@@ -88,6 +90,24 @@ sub _check_bundle {
     }
 }
 
+#
+# We want to make sure that the dirname of path exist
+#
+sub _write_config_h {
+    my ($self, $path) = @_;
+
+    #
+    # We do not mind about suffixes, only directory name
+    # Note that File::Basename says that fileparse()
+    # should be used instead of dirname()
+    #
+    my ($filename, $dirs, $suffix) = fileparse($path);
+    if ($dirs) {
+        make_path($dirs); # This will croak in case of failure
+    }
+    $self->write_config_h($path);
+}
+
 #
 # Config::AutoConf does not honor all the found headers, so we generate
 # ourself the prologue
@@ -214,7 +234,7 @@ Config::AutoConf::INI - Drive Config::AutoConf with an INI file
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
